flutter_stasis_secure library
Classes
- FakeSafeDataSecureAdapter
- In-memory adapter used by tests and local development.
- SafeDataSecureAdapter
- Contract for secure persistence backends used by Stasis safe data.
-
SafeDataSecureBinding<
T> -
Explicit secure persistence binding for a
SafeDatafield. - SafeDataSecureRecord
- Encoded value stored by a secure adapter.
Typedefs
-
SafeDataSecureDecoder<
T> = T Function(String value) - Decodes a persisted value back into the field type.
-
SafeDataSecureEncoder<
T> = String Function(T value) - Encodes a field value before secure persistence.