FakeSafeDataSecureAdapter class final
In-memory adapter used by tests and local development.
- Implemented types
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
delete(
String key) → Future< void> -
Deletes the record stored under
key, if any.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
read(
String key) → Future< SafeDataSecureRecord?> -
Reads the record stored under
key, if any.override -
toString(
) → String -
A string representation of this object.
inherited
-
write(
SafeDataSecureRecord record) → Future< void> -
Persists a record under its logical key.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited